Documentation
¶
Index ¶
- Constants
- Variables
- func InitLogger(development bool, logFilePath string)
- type EchoServer
- type Runner
- func NewBidirConnection(tcpConn net.Conn, wsConn *websocket.Conn, tcpReadTimeout time.Duration, ...) Runner
- func NewHTTPClient(listenTCP, remoteServer string, tunnelType int, mtu int, callback func(fd int), ...) Runner
- func NewStunnelBiDirection(localConn net.Conn, remoteConn *tls.UConn, mtu int) Runner
- type StunnelBiDirection
- type WebSocketBiDirection
Constants ¶
const (
// BufferSize is the size of the intermediate buffer for network packets
BufferSize = 1024
)
const Stunnel = 2
const WSTunnel = 1
Variables ¶
var Channel = make(chan string)
var Logger *zap.SugaredLogger
Functions ¶
func InitLogger ¶
InitLogger initializes the logger.
Types ¶
type EchoServer ¶
type EchoServer struct {
// contains filtered or unexported fields
}
EchoServer simple web socket server for testing.
type Runner ¶
type Runner interface {
Run() error
}
Runner defines a basic interface with only a Run() function
func NewBidirConnection ¶
func NewHTTPClient ¶
type StunnelBiDirection ¶
type StunnelBiDirection struct {
// contains filtered or unexported fields
}
StunnelBiDirection creates an object to transfer data between the TCP clients and remote server in bidirectional way
func (*StunnelBiDirection) Run ¶
func (s *StunnelBiDirection) Run() error
type WebSocketBiDirection ¶
type WebSocketBiDirection struct {
// contains filtered or unexported fields
}
WebSocketBiDirection Creates an object to transfer data between the TCP clients and remote server in bidirectional way
func (*WebSocketBiDirection) Run ¶
func (b *WebSocketBiDirection) Run() error
Click to show internal directories.
Click to hide internal directories.